@@ -1,10 +1,15 @@
+# -*- encoding: utf-8 -*-
+import os
 import re
 import sys
 import itertools
 import json
 
 import lxml.html
-from picklecache import get
+from picklecache import cache
+import requests
+
+get = cache(os.path.expanduser('~/.tlevine'))(requests.get)
 
 def github(username):
     def pages():
@@ -29,9 +34,10 @@ def scraperwiki(url = 'https://classic.scraperwiki.com/profiles/tlevine/index.ht
     html.make_links_absolute(url)
     for href in html.xpath('//li[@class="code_object_line"]/descendant::h3/a[position()=2]/@href'):
         yield re.sub(r'index.html$', '', str(href))
-    nexts = html.xpath('//a[text()="Next »"]/@href')
+    nexts = html.xpath(u'//a[text()="Next »"]/@href')
     if nexts != []:
-        yield from scraperwiki(nexts[0])
+        for scraper in scraperwiki(nexts[0]):
+            yield scraper
 
 def gitorious():
     url = 'https://gitorious.org/tlevine.xml'
